Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/vm.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel Hansson <github@hanssonit.se>2018-12-02 19:22:52 +0300
committerGitHub <noreply@github.com>2018-12-02 19:22:52 +0300
commitb44b65053d12f41e7b190606cf5c5b5315182d3b (patch)
treef36f0466b329b7bef54c74ff76c2d85c0e9632d1 /nextcloud_update.sh
parent8c21391a44e929a5fb5c8c62eef89a18f864842b (diff)
update docker-ce to overlay2 for old installations (#728)
Diffstat (limited to 'nextcloud_update.sh')
-rw-r--r--nextcloud_update.sh11
1 files changed, 8 insertions, 3 deletions
diff --git a/nextcloud_update.sh b/nextcloud_update.sh
index 4cffccdf..3f925f41 100644
--- a/nextcloud_update.sh
+++ b/nextcloud_update.sh
@@ -29,10 +29,15 @@ then
apt-mark hold mariadb*
fi
-# Hold docker-ce since it breaks devicemapper
-if which docker > /dev/null
+# Update docker-ce to overlay2 since devicemapper is deprecated
+if [ -f /etc/systemd/system/docker.service ]
then
- apt-mark hold docker-ce
+ if grep -q "devicemapper" /etc/systemd/system/docker.service
+ then
+ echo "Changing to Overlay2 for Docker CE..."
+ echo "Please report any issues to $ISSUES."
+ run_static_script docker_overlay2
+ fi
fi
apt update -q4 & spinner_loading